# Vaultwarden: Self-Hosted Password Manager

Vaultwarden is an unofficial, lightweight Bitwarden server implementation written in Rust. It provides a secure, self-hosted solution for storing and managing passwords, notes, credit cards, and other sensitive information across all your devices.

## Key Features

*   **Cross-Platform Compatibility**: Works with all official Bitwarden clients (mobile, desktop, browser extensions)
*   **Password Generator**: Create strong, unique passwords for each service
*   **Secure Notes & Cards**: Store sensitive information beyond just passwords
*   **Vault Health Reports**: Identify weak, reused, or compromised passwords
*   **Two-Factor Authentication**: Add an extra layer of security to your vault
*   **End-to-End Encryption**: Your data is encrypted on your device before being sent to the server
*   **Self-Hosted**: Complete control over your data with no third-party involvement
*   **Organization Support**: Share selected passwords with family members or team members

## Documentation

For comprehensive documentation about Vaultwarden, visit the [official GitHub repository](https://github.com/dani-garcia/vaultwarden).

## Getting Started with Vaultwarden

### Accessing Vaultwarden
1.  **URL**: Access Vaultwarden locally via `http://localhost:8200/` (or your configured external URL).
2.  **First Use**: On first access, you'll need to create a master account. This will be your main admin account.

### Basic Usage

1.  **Creating Your Account**:
    *   Visit your Vaultwarden instance and click "Create Account"
    *   Set up a strong master password (this is your encryption key - if you forget it, your data cannot be recovered)
    *   Consider setting up email verification if you've configured SMTP

2.  **Installing Clients**:
    *   Download the Bitwarden client for your devices (mobile, desktop, browser extensions)
    *   When configuring the client, select "Self-hosted" and enter your Vaultwarden server URL

3.  **Adding Passwords**:
    *   Use the "+" button to add new entries to your vault
    *   Create separate items for logins, secure notes, cards, or identities
    *   Use the password generator to create strong, unique passwords

4.  **Organizing Your Vault**:
    *   Create folders to organize your entries
    *   Use custom fields for additional information
    *   Add attachments when needed

5.  **Administrative Tasks** (with Admin Token):
    *   Access the admin panel at `/admin` with your configured admin token
    *   Manage users, organizations, and server settings
    *   Monitor usage statistics and perform database backups

## Use Cases within Changemaker

*   **Team Password Management**: Securely share access credentials among campaign team members.
*   **Secure Credential Storage**: Store API keys, tokens, and other sensitive information needed for integrations.
*   **Enhance Security Posture**: Encourage strong, unique passwords for all campaign services and tools.
*   **Campaign Continuity**: Ensure critical access information is safely stored and available to authorized team members.
*   **Volunteer Management**: Temporarily share limited access to certain resources with volunteers.

## Administration

Vaultwarden includes an admin panel that can be accessed at `/admin` from your instance. This requires the admin token that was generated during setup. The admin panel allows you to:

* Manage user accounts
* Configure server settings
* Control user invitations and registrations
* Monitor system usage
* Perform database operations

To enhance security, consider these best practices:
* Keep your Vaultwarden instance updated
* Enable 2FA for all accounts
* Regularly backup your vault data
* Review vault access logs periodically

## Further Information

*   **Vaultwarden GitHub**: [https://github.com/dani-garcia/vaultwarden](https://github.com/dani-garcia/vaultwarden)
*   **Bitwarden Documentation**: [https://bitwarden.com/help/](https://bitwarden.com/help/)
*   **Vaultwarden Wiki**: [https://github.com/dani-garcia/vaultwarden/wiki](https://github.com/dani-garcia/vaultwarden/wiki)
